AUTH = {
    "access_token": "1A7zSU7kG5cCTIfAY1i32oUvW0Z5",
    "expires_in": "3599"
}
B2C = {
    "ConversationID": "AG_20210929_00004d202f0f95df3b88",
    "OriginatorConversationID": "62947-35666607-1",
    "ResponseCode": "0",
    "ResponseDescription": "Accept the service request successfully."
}
EXPRESS_SIM = {
    "MerchantRequestID": "25811-34836046-1",
    "CheckoutRequestID": "ws_CO_290920211026123753",
    "ResponseCode": "0",
    "ResponseDescription": "Success. Request accepted for processing",
    "CustomerMessage": "Success. Request accepted for processing"
}
EXPRESS_QUERY = {
    "ResponseCode": "0",
    "ResponseDescription": "The service request has been accepted successsfully",
    "MerchantRequestID": "25811-34836046-1",
    "CheckoutRequestID": "ws_CO_290920211026123753",
    "ResultCode": "1032",
    "ResultDesc": "Request cancelled by user"
}
C2B_REG = {
    "OriginatorCoversationID": "31325-15385456-1",
    "ResponseCode": "0",
    "ResponseDescription": "success"
}

C2B_SIM = {
    "OriginatorCoversationID": "54609-35532657-1",
    "ResponseCode": "0",
    "ResponseDescription": "Accept the service request successfully."
}

BAL = {
    "OriginatorConversationID": "18795-24511603-1",
    "ConversationID": "AG_20210929_00005b98cef717428741",
    "ResponseCode": "0",
    "ResponseDescription": "Accept the service request successfully."
}

TRANSACTION_STATUS = {
    "OriginatorConversationID": "117879-42739630-1",
    "ConversationID": "AG_20211002_0000635cc3241d2055a8",
    "ResponseCode": "0",
    "ResponseDescription": "Accept the service request successfully."
}
B2B = {
    'OriginatorConversationID': '77333-45263982-1',
    'ConversationID': 'AG_20211003_00004e5173b463fe1447',
    'ResponseCode': '0',
    'ResponseDescription': 'Accept the service request successfully.'
}
